Installation from source - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Installation from source

To use any version of Betty, including the latest, bleeding-edge development version, install Betty from source.

See also

Follow Installing a development environment if you are looking to develop Betty itself.

## Requirements

- Linux, macOS, or Windows

- Python 3.11+

- Node.js 20+ (optional, see npm)

- Bash

## Instructions

1. `git clone https://github.com/bartfeenstra/betty.git`

2. `cd betty`

3. `./bin/build`